@@ -575,7 +575,7 @@ void BweibDpCorScrmcmc(double survData[],
              BweibDpCorScr_updateCP(beta1, beta2, beta3, alpha1, alpha2, alpha3, kappa1, kappa2, kappa3, gamma, V1, V2, V3, survTime1, survTime2, survEvent1, case01, case11, cluster, survCov1, survCov2, survCov3, n_j, mu_all, Sigma_all, c, accept_V, mu0, Psi0, zeta0, rho0, tau, &nClass_DP, rr);
 
             
-            BweibDpCorScr_updatePP(n, &tau, aTau, bTau, &nClass_DP);
+            BweibDpCorScr_updatePP(J, &tau, aTau, bTau, &nClass_DP);
         }
 
                 
